/*

This function Initializes the NFC and the Interrupts. 
Also, this function initialzes the  "WriteData" buffer 
which is written to Nand Flash

*/



#include "Extern_Declaration.h"

/**********************************************************************/

void Init(void)
{
	
	
	// PLL initialization
	
	*pPLL_CTL = MSELECT;
	ssync();
	idle();
	*pPLL_DIV = CSELECT | SSELECT;
	ssync();
	
	
	
	//initialize the buffer to write into NAND flash
	

	for(i=0; i<Flash_Page_Size; i++)
	{
		WriteData[i] = i+1;
	}
	
	//Port config to enable NFC
	
	*pPORTJ_FER = PJ1 | PJ2;
	*pPORTJ_MUX = 0;
		
	// Set up NFC
	
	*pNFC_CTL = ((WR_DLY & Write_Strobe_Delay) | (RD_DLY & (Read_Strobe_Delay << 4)));
	
	if(NFC_PAGE_SIZE == 512)
	{
		*pNFC_CTL |= PG_SIZE;
	}
		
	
	*pNFC_RST = ECC_RST;		//clear ECC registers and counters
	
	// Unmask the IRQ bits. 
	*pNFC_IRQMASK = nWR_DONE | nNBUSYIRQ | nWB_OVF | WB_EDGE | RD_RDY;

	//enable DMA22 interrupt for NFC
	
	register_handler(ik_ivg8, NFC_ISR);		
	*pSIC_IMASK2 |= IRQ_DMA22;
	ssync();
	
	//enable NFC Error interrupt
	
	register_handler(ik_ivg7, NFC_IRQSTAT_ISR);		
	*pSIC_IMASK1 |= IRQ_NFC_ERR;
	ssync();
	
	
	/* 
	NBUSYIRQ sets as soon as ND_RB is enabled in PortJ_FER
	So clear the flag here. 
	*/
	
	NBUSY_Flag = 0;
			
	printf("Initialization Completed\n");
		
}

/**********************************************************************/

