/*

This function erases a block. Once the Block Erase is completed
Flash status register is read to know if the Erase operation is
successful or not. If the Erase peration fails, then the Block is 
treated as Bad Block and the BadBlockTable is updated accordingly.

Parameter to be passed: BlockNo
Returns: None


*/




#include "Extern_Declaration.h"

/**********************************************************************/

void BlockErase(unsigned int Eblock)
{
	
	//Check if the BlockNo is good or bad.
	
	if(BadBlockTable[Eblock] == 0xBD)
	{
		printf(" %d is a Bad Block...STOP \n", Eblock);
		//while(1);
	}
	
		
	// Wait till write buffer is empty:
	
	while(!(*pNFC_STAT & WB_EMPTY));
	
	 // Erase Block Command: 0x60, 0xD0: 
	
	*pNFC_CMD =  BlockEraseCmd[0];
	
	/* 
	
	Set up the address cycles depending on Block number passed:
	
	For Erase, we send the Block no:
	
	1st Address Cycle: A18-A19 (bit6 and bit7. rest should be 0)	 
	2nd Address Cycle: A20-A27
	3rd Address Cycle: A28-A29 
	
	*/
	short temp_Block = Eblock;
	 
	Eblock = Eblock & 3;	// Get bits A18 and A19 from Block address
	Eblock = Eblock << 6;	// Shift to send these two bits at position 6 and 7. rest all 0
		
	*pNFC_ADDR = Eblock;	// This sends first two bits of block address	
	
	
	// Block address till 1023
	
	Eblock = temp_Block;
	Eblock = Eblock & 0x3FC;	// Mask to get A20-A27	
	Eblock = Eblock >> 2;		// Because A18 and A19 are already sent out
	
	*pNFC_ADDR = Eblock;
	
	// Block address greater than 1023
	
	Eblock = temp_Block;
	Eblock = Eblock & 0xFC00;	// Mask to get A28-A30
	Eblock = Eblock >> 10;		// Because A18-A27 are already sent out
	
	*pNFC_ADDR = Eblock;

	
	// Wait till write buffer is empty:
	
	while(!(*pNFC_STAT & WB_EMPTY));
	
	*pNFC_CMD =  BlockEraseCmd[1];
	
	
	//Wait till NBUSY Flag sets.
	
	while(!(NBUSY_Flag));
	NBUSY_Flag = 0;

	/* 
	Read Flash Status Register to know if Erase operation failed.
	If so, update the BadBlock Table in the Flash
	*/
	
	
	Read_Flash_Status_Register();
	
	if((Flash_Status & 0x01) != 0)
	{
		// First update the copy in the internal memory. 
		BadBlockTable[BlockNo] = 0xBD;
		
		// Now write this table into Flash. Where to write is given 
		BlockErase(ResBlockNo);
		PageWrite(0, ResBlockNo, &BadBlockTable[0]);
		
	}

	else if(Flag1 == 1)
	{
		printf("Block Erase Completed \n");
	}
	
}


